/*Our code and data cannot be shared, because it has state identifiers that are not publicly available.
The data used here is publicly available. This sample code runs a factor analysis on age 
standardized death rates for selected causes of death by state. Only white males aged 15-64 and years  
2000-2009 are included. This data was taken from CDC wonder.
This code is for Stata.*/

/*Change to your local directory*/
insheet using ".../state_death_matrix.csv"

/*You should now have a cause of death by state matrix*/
factor homicide-transportaccidents
screeplot
graph save  ".../Scree_Plot.gph"

/*This screeplot suggests that we should retain 3 factors*/
factor homicide-transportaccidents, factors(3)

/*Varimax Rotation.*/
rotate, orthogonal

/*Factor score prediction using the regression approach.*/
predict factor1 factor2 factor3, regression
keep statefips factor1-factor3
xmlsave ".../Factor_Scores.csv", doctype(excel) replace
clear

/*Save the factor loadings*/
insheet using ".../Causes_of_Death.csv"
matrix loadings = e(r_L)
svmat loadings 
xmlsave ".../Factor_Loadings.csv", doctype(excel) replace
clear

/*Save the Eigenvalues*/
matrix eigenvalues = e(Ev)
svmat eigenvalues
xpose, clear
rename v1 eigenvalue
gen percent=eigenvalue/_N
gen cumulative_percent = sum(percent)
xmlsave ".../Eigenvalues.csv", doctype(excel) replace
clear
clear matrix

